
#ifndef VTKPVVTKEXTENSIONSIOIMAGE_EXPORT_H
#define VTKPVVTKEXTENSIONSIOIMAGE_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSIOIMAGE_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSIOIMAGE_EXPORT
#  define VTKPVVTKEXTENSIONSIOIMAGE_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSIOIMAGE_EXPORT
#    ifdef VTKExtensionsIOImage_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSIOIMAGE_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSIOIMAGE_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSIOIMAGE_NO_EXPORT
#    define VTKPVVTKEXTENSIONSIOIMAGE_NO_EXPORT 
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSIOIMAGE_DEPRECATED
#  define VTKPVVTKEXTENSIONSIOIMAGE_DEPRECATED __declspec(deprecated)
#endif

#ifndef VTKPVVTKEXTENSIONSIOIMAGE_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSIOIMAGE_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSIOIMAGE_EXPORT VTKPVVTKEXTENSIONSIOIMAGE_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSIOIMAGE_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSIOIMAGE_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSIOIMAGE_NO_EXPORT VTKPVVTKEXTENSIONSIOIMAGE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSIOIMAGE_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSIOIMAGE_NO_DEPRECATED
#  endif
#endif

#endif /* VTKPVVTKEXTENSIONSIOIMAGE_EXPORT_H */
