
#ifndef VTKPVVTKEXTENSIONSAMR_EXPORT_H
#define VTKPVVTKEXTENSIONSAMR_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSAMR_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSAMR_EXPORT
#  define VTKPVVTKEXTENSIONSAMR_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSAMR_EXPORT
#    ifdef VTKExtensionsAMR_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSAMR_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSAMR_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSAMR_NO_EXPORT
#    define VTKPVVTKEXTENSIONSAMR_NO_EXPORT 
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSAMR_DEPRECATED
#  define VTKPVVTKEXTENSIONSAMR_DEPRECATED __declspec(deprecated)
#endif

#ifndef VTKPVVTKEXTENSIONSAMR_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSAMR_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSAMR_EXPORT VTKPVVTKEXTENSIONSAMR_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSAMR_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSAMR_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSAMR_NO_EXPORT VTKPVVTKEXTENSIONSAMR_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSAMR_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSAMR_NO_DEPRECATED
#  endif
#endif

#endif /* VTKPVVTKEXTENSIONSAMR_EXPORT_H */
